@@ -34,29 +34,33 @@ def universalizeDateTime( dt ):
         return dt.astimezone(datetime.timezone.utc)
     return dt.replace( tzinfo=datetime.timezone.utc )
 
+def truncateVersion( nlVersion ):
+    '''drop patch-level part of version number, if any'''
+    return '.'.join(nlVersion.split('.')[:-1]) if nlVersion.count('.') > 1 else nlVersion
+
 def checkProcesses( liveInstances ):
-    '''
-    startedInstances = []
-    # get details of launched instances from the json file
-    with open( instancesFilePath, 'r') as jsonInFile:
-        try:
-            startedInstances = json.load(jsonInFile)  # an array
-        except Exception as exc:
-            logger.warning( 'could not load json (%s) %s', type(exc), exc )
-    '''
+    '''check that the expected process is running on each instance'''
     logger.info( 'checking %d instance(s)', len(liveInstances) )
 
     #maybe should weed out some instances
     goodInstances = liveInstances
 
     cmd = "ps -ef | grep -v grep | grep 'LoadGeneratorAgent start' > /dev/null"
+    #cmd = "free --mega 1>&2 ; ps -ef | grep -v grep | grep 'LoadGeneratorAgent start' > /dev/null"
     # check for a running agent process on each instance
     stepStatuses = tellInstances.tellInstances( goodInstances, cmd,
         timeLimit=30*60,
         knownHostsOnly=True
         )
     #logger.info( 'cmd statuses: %s', stepStatuses )
-
+    errorsByIid = {}
+    for status in stepStatuses:
+        if status['status']:
+            # might like to be more selective here
+            #logger.info( 'status: %s', status )
+            errorsByIid[ status['instanceId'] ] = status
+    logger.debug( 'errorsByIid: %s', errorsByIid )
+    return errorsByIid
 
 def retrieveLogs( liveInstances, neoloadVersion ):
     '''
@@ -75,12 +79,8 @@ def retrieveLogs( liveInstances, neoloadVersion ):
     goodInstances = liveInstances
     logger.info( 'retrieving logs for %d instance(s)', len(goodInstances) )
 
-    if neoloadVersion == '7.10':
-        agentLogFilePath = '/root/.neotys/neoload/v7.10/logs/*.log'
-    elif neoloadVersion == '7.7':
-        agentLogFilePath = '/root/.neotys/neoload/v7.7/logs/*.log'
-    else:
-        agentLogFilePath = '/root/.neotys/neoload/v7.6/logs/*.log'
+    truncVersion = truncateVersion( neoloadVersion )
+    agentLogFilePath = '/root/.neotys/neoload/v%s/logs/*.log' % truncVersion
 
     # download the agent.log file from each instance
     stepStatuses = tellInstances.tellInstances( goodInstances,
@@ -248,6 +248,17 @@ def parseLogLevel( arg ):
 
     return setting
 
+def purgeHostKeys( instanceRecs ):
+    '''try to purgeKnownHosts; warn if any exception'''
+    logger.info( 'purgeKnownHosts for %d instances', len(instanceRecs) )
+    try:
+        ncs.purgeKnownHosts( instanceRecs )
+    except Exception as exc:
+        logger.warning( 'exception from purgeKnownHosts (%s) %s', type(exc), exc, exc_info=True )
+        return 1
+    else:
+        return 0
+
 def queryMongoForLGs( mongoHost ):
     import pymongo
     mongoPort = 27017
@@ -279,7 +290,17 @@ def queryNlWebForResources( nlWebUrl, nlWebToken ):
     url = nlWebUrl+'/v3/resources/zones'
 
     logger.info( 'querying: %s', nlWebUrl )
-    resp = requests.get( url, headers=headers )
+    # set long timeouts for requests.get() as a tuple (connection timeout, read timeout) in seconds
+    timeouts = (30, 120)
+    try:
+        resp = requests.get( url, headers=headers, timeout=timeouts )
+    except requests.ConnectionError as exc:
+        logger.warning( 'ConnectionError exception (%s) %s', type(exc), exc )
+        return None
+    except Exception as exc:
+        logger.warning( 'Exception (%s) %s', type(exc), exc )
+        return None
+
     if (resp.status_code < 200) or (resp.status_code >= 300):
         logger.warning( 'error code from server (%s) %s', resp.status_code, resp.text )
     else:
@@ -292,6 +313,7 @@ def queryNlWebForResources( nlWebUrl, nlWebToken ):
             for lg in zone['loadgenerators']:
                 logger.debug( '  LG "%s" %s %s', lg['name'], lg['version'], lg['status'] )
             logger.info( '  %d LGs listed by nlweb in Zone %s', len(zone['loadgenerators']), zone['id'] )
+            logger.info( '  %d controllers listed by nlweb in Zone %s', len(zone['controllers']), zone['id'] )
 
 
 if __name__ == "__main__":
@@ -302,12 +324,13 @@ if __name__ == "__main__":
     logging.basicConfig(format=logFmt, datefmt=logDateFmt)
     logger.setLevel(logging.WARNING)
 
-    ap = argparse.ArgumentParser( description=__doc__, fromfile_prefix_chars='@' )
-    ap.add_argument( '--dataDirPath', help='the path to the directory for input and output data' )
-    ap.add_argument( '--neoloadVersion', default ='7.7', help='version of neoload to check for' )
+    ap = argparse.ArgumentParser( description=__doc__, fromfile_prefix_chars='@', formatter_class=argparse.ArgumentDefaultsHelpFormatter )
+    ap.add_argument( '--dataDirPath', required=True, help='the path to the directory for input and output data' )
+    ap.add_argument( '--neoloadVersion', default ='7.10', help='version of neoload to check for' )
     ap.add_argument( '--nlWebUrl', help='the URL of a neoload web server to query' )
     ap.add_argument( '--nlWebToken', help='a token for authorized access to a neoload web server' )
     ap.add_argument( '--logLevel', default ='info', help='verbosity of log (e.g. debug, info, warning, error)' )
+    ap.add_argument( '--terminateBad', type=ncs.boolArg, default=False, help='whether to terminate instances found bad' )
     args = ap.parse_args()
 
     logLevel = parseLogLevel( args.logLevel )
@@ -323,7 +346,10 @@ if __name__ == "__main__":
         if not args.nlWebToken:
             logger.warning( 'please pass --nlWebToken if you want to query an nlWeb server')
         else:
-            queryNlWebForResources( args.nlWebUrl, args.nlWebToken )
+            url = args.nlWebUrl
+            if url == 'SAAS':
+                url = 'https://neoload-api.saas.neotys.com'
+            queryNlWebForResources( url, args.nlWebToken )
     if False:
         mongoHost = 'yourNLWebMongoHost'
         queryMongoForLGs( mongoHost )
@@ -352,13 +378,15 @@ if __name__ == "__main__":
     for iid in startedIids:
         reqParams = {"show-device-info":True}
         try:
-            response = ncs.queryNcsSc( 'instances/%s' % iid, authToken, reqParams=reqParams, maxRetries=1)
+            response = ncs.queryNcsSc( 'instances/%s' % iid, authToken, reqParams=reqParams, maxRetries=10)
         except Exception as exc:
             logger.warning( 'querying instance status got exception (%s) %s',
                 type(exc), exc )
         else:
             if response['statusCode'] != 200:
-                logger.warning( 'cloud server returned bad status code %s', response['statusCode'] )
+                logger.error( 'cloud server returned bad status code %s', response['statusCode'] )
+                # drastic hack to exit this early
+                sys.exit( 1 )
                 continue
             inst = response['content']
             instState = inst['state']
@@ -381,13 +409,15 @@ if __name__ == "__main__":
     #showLogs( dataDirPath )
 
     nlWebWanted = bool( args.nlWebUrl )
-    terminatedIids = []
+    iidsToTerminate = []
     errorsByIid = checkLogs( liveInstances, dataDirPath, nlWebWanted )
     if errorsByIid:
         badIids = list( errorsByIid.keys() )
-        logger.warning( 'terminating %d error-logged instance(s)', len( badIids ) )
-        ncs.terminateInstances( authToken, badIids )
-        terminatedIids.extend( badIids )
+        logger.warning( '%d error-logged instance(s)', len( badIids ) )
+        if len( badIids ) > 1 and len( badIids ) == len( liveInstances ):
+            logger.warning( 'NOT terminating all instances, even though all had errors' )
+        else:
+            iidsToTerminate.extend( badIids )
 
     forwarders = findForwarders()
     forwardersByPort = { fw['port']: fw for fw in forwarders }
@@ -397,11 +427,19 @@ if __name__ == "__main__":
 
     badIids = checkForwarders( liveInstances,  forwarders )
     if badIids:
-        logger.warning( 'terminating %d not-forwarded instance(s)', len( badIids ) )
-        ncs.terminateInstances( authToken, badIids )
-        terminatedIids.extend( badIids )
+        logger.warning( '%d not-forwarded instance(s)', len( badIids ) )
+        #ncs.terminateInstances( authToken, badIids )
+        iidsToTerminate.extend( badIids )
  
-    terminatedIids = set( terminatedIids )
+    iidsToTerminate = set( iidsToTerminate )
+    terminatedIids = []
+    if args.terminateBad and iidsToTerminate:
+        logger.info( 'terminating %d bad instances', len(iidsToTerminate) )
+        ncs.terminateInstances( authToken, list( iidsToTerminate ) )
+        terminatedIids = list( iidsToTerminate )
+        toPurge = [inst for inst in startedInstances if inst['instanceId'] in iidsToTerminate]
+        purgeHostKeys( toPurge )
+
     stillLive = [inst for inst in liveInstances if inst['instanceId'] not in terminatedIids]
     logger.info( '%d instances are still live', len(stillLive) )
     with open( dataDirPath + '/liveAgents.json','w' ) as outFile:
