@@ -651,7 +651,10 @@ def rsyncFromRemote1( srcFileName, destFilePath, inst, timeLimit ):
 
     destFilePathFull = os.path.realpath(os.path.abspath( destFilePath ))
     timeLimitMinutes = max( 1, int( timeLimit/60 ) )
-    cmd = [ 'rsync', '--time-limit=%d' % timeLimitMinutes, '-a', '-e', 'ssh -p ' + str(port), user+'@'+host+':~/'+srcFileName,
+    sshClause = 'ssh -o ServerAliveInterval=%d -o ServerAliveCountMax=%d -p %d' \
+        % (g_.serverAliveInterval, g_.serverAliveCountMax, port)
+    cmd = [ 'rsync', '--time-limit=%d' % timeLimitMinutes, '-a', '-e', sshClause,
+        user+'@'+host+':~/'+srcFileName,
         destFilePathFull+'/'
     ]
     logger.info( 'retrieving from %s', inst['instanceId'] )
@@ -1293,6 +1296,9 @@ def runBatch( **kwargs ):
     logger.info( 'args.outDataDir: %s', args.outDataDir )
     os.makedirs( g_.dataDirPath, exist_ok=True )
 
+    if args.cookie:
+        os.environ['NCS_COOKIE'] = args.cookie
+
     signal.signal( signal.SIGTERM, sigtermHandler )
     myPid = os.getpid()
     logger.debug('procID: %s', myPid)
@@ -1502,6 +1508,7 @@ def createArgumentParser():
         fromfile_prefix_chars='@', formatter_class=argparse.ArgumentDefaultsHelpFormatter )
     ap.add_argument( '--commonInFilePath', help='a file to upload initially to all instances' )
     ap.add_argument( '--authToken', required=True, help='the NCS authorization token to use (required)' )
+    ap.add_argument( '--cookie', help='for internal use only' )
     ap.add_argument( '--outDataDir', help='output data darectory', default='./data/' )
     ap.add_argument( '--pushDeviceLocs', type=boolArg, default=False, help='whether to store device location on each launched instance' )
     ap.add_argument( '--encryptFiles', type=boolArg, default=True, help='whether to encrypt files on launched instances' )
